Apply compartment characteristics from model. In practice, only compartment infusion duration needs to be applied.
Source:R/dataset.R
apply_compartment_characteristics.RdApply compartment characteristics from model. In practice, only compartment infusion duration needs to be applied.